package com.ruoyi.ss.account.service;

import com.ruoyi.ss.account.domain.Account;
import com.ruoyi.ss.account.domain.AccountQuery;
import com.ruoyi.ss.account.domain.AccountVO;
import com.ruoyi.ss.account.domain.enums.AccountType;

import java.util.List;
import java.util.Map;

/**
 * 用户账户Service接口
 *
 * @author ruoyi
 * @date 2024-03-26
 */
public interface AccountService
{
    /**
     * 查询用户账户
     *
     * @param accountId 用户账户主键
     * @return 用户账户
     */
    public AccountVO selectSmAccountByAccountId(Long accountId);

    /**
     * 查询用户账户列表
     *
     * @param smAccount 用户账户
     * @return 用户账户集合
     */
    public List<AccountVO> selectSmAccountList(AccountQuery smAccount);

    /**
     * 新增用户账户
     *
     * @param account 用户账户
     * @return 结果
     */
    public int insertSmAccount(Account account);

    /**
     * 修改用户账户
     *
     * @param account 用户账户
     * @return 结果
     */
    public int updateSmAccount(Account account);

    /**
     * 批量删除用户账户
     *
     * @param accountIds 需要删除的用户账户主键集合
     * @return 结果
     */
    public int deleteSmAccountByAccountIds(Long[] accountIds);

    /**
     * 删除用户账户信息
     *
     * @param accountId 用户账户主键
     * @return 结果
     */
    public int deleteSmAccountByAccountId(Long accountId);

    /**
     * 查询列表并分组
     */
    Map<String, List<AccountVO>> selectSmAccountGroup(AccountQuery dto);

    /**
     * 判断这个账号是不是用户的
     * @param userId 用户id
     * @param accountNo 账号
     */
    boolean validateUserHasAccount(Long userId, String accountNo, AccountType accountType);

    /**
     * 查询用户的微信账户
     * @param userId 用户id
     */
    AccountVO selectUserWxAccount(Long userId);

    /**
     * 查询用户的支付宝账户
     * @param userId 用户id
     */
    AccountVO selectUseAliAccount(Long userId);

    /**
     * 设置默认账户
     * @param userId 用户id
     * @param accountId 账户id
     */
    boolean setDefault(Long userId, Long accountId);

    /**
     * 查询一个
     */
    AccountVO selectOne(AccountQuery query);

    /**
     * 根据用户查询
     */
    List<AccountVO> selectByUserId(Long userId);

    /**
     * 查询用户账户
     * @param userId 用户ID
     * @param type 账户类型
     */
    List<AccountVO> selectUserAccountByType(Long userId, String type);
}
